@@ -138,6 +138,20 @@ class CControllerWidgetNavTreeView extends CControllerWidget {
 				}
 			}
 
+			// Drop all inaccessible triggers.
+			if ($problems_per_trigger) {
+				$triggers = API::Trigger()->get([
+					'output' => [],
+					'triggerids' => array_keys($problems_per_trigger),
+					'monitored' => true,
+					'preservekeys' => true
+				]);
+
+				$problems_per_trigger = array_intersect_key($problems_per_trigger, $triggers);
+
+				unset($triggers);
+			}
+
 			// Select lowest severity to reduce amount of data returned by API.
 			$severity_min = min(zbx_objectValues($sysmaps, 'severity_min'));
 
@@ -145,14 +159,13 @@ class CControllerWidgetNavTreeView extends CControllerWidget {
 			if ($host_groups) {
 				$triggers = API::Trigger()->get([
 					'output' => ['triggerid'],
+					'selectHostGroups' => ['groupid'],
 					'groupids' => array_keys($host_groups),
-					'skipDependent' => true,
-					'selectGroups' => ['groupid'],
 					'preservekeys' => true
 				]);
 
 				foreach ($triggers as $trigger) {
-					foreach ($trigger['groups'] as $host_group) {
+					foreach ($trigger['hostgroups'] as $host_group) {
 						$triggers_per_host_groups[$host_group['groupid']][$trigger['triggerid']] = true;
 					}
 					$problems_per_trigger[$trigger['triggerid']] = $this->problems_per_severity_tpl;
@@ -167,7 +180,6 @@ class CControllerWidgetNavTreeView extends CControllerWidget {
 					'output' => ['triggerid'],
 					'selectHosts' => ['hostid'],
 					'hostids' => array_keys($hosts),
-					'skipDependent' => true,
 					'preservekeys' => true,
 					'monitored' => true
 				]);
@@ -184,20 +196,11 @@ class CControllerWidgetNavTreeView extends CControllerWidget {
 
 			// Count problems per trigger.
 			if ($problems_per_trigger) {
-				$triggers = API::Trigger()->get([
-					'output' => [],
-					'selectGroups' => ['groupid'],
-					'triggerids' => array_keys($problems_per_trigger),
-					'skipDependent' => true,
-					'preservekeys' => true,
-					'monitored' => true
-				]);
-
 				$problems = API::Problem()->get([
 					'output' => ['objectid', 'severity'],
 					'source' => EVENT_SOURCE_TRIGGERS,
 					'object' => EVENT_OBJECT_TRIGGER,
-					'objectids' => array_keys($triggers),
+					'objectids' => array_keys($problems_per_trigger),
 					'severities' => range($severity_min, TRIGGER_SEVERITY_COUNT - 1),
 					'preservekeys' => true
 				]);
@@ -450,8 +453,8 @@ class CControllerWidgetNavTreeView extends CControllerWidget {
 		for ($severity = TRIGGER_SEVERITY_NOT_CLASSIFIED; $severity < TRIGGER_SEVERITY_COUNT; $severity++) {
 			$this->problems_per_severity_tpl[$severity] = 0;
 			$severity_config[$severity] = [
-				'name' => getSeverityName($severity),
-				'style_class' => getSeverityStatusStyle($severity)
+				'name' => CSeverityHelper::getName($severity),
+				'style_class' => CSeverityHelper::getStatusStyle($severity)
 			];
 		}
 
