@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,18 +23,38 @@
  * @var CView $this
  */
 
+$form_items = [$data['messages']];
+
+if ($data['success']) {
+	$row_decription = [
+		(new CTextArea('', $data['output']))
+			->setWidth(ZBX_TEXTAREA_BIG_WIDTH)
+			->addClass('monospace-font')
+			->addClass('active-readonly')
+			->setReadonly(true)
+	];
+
+	if ($data['type'] == ZBX_SCRIPT_TYPE_WEBHOOK) {
+		$row_decription[] = new CVar('debug', json_encode($data['debug']));
+		$row_decription[] = new CDiv(
+			(new CLinkAction('Open log'))
+				->setId('script_execution_log')
+				->addClass($data['debug'] ? '' : ZBX_STYLE_DISABLED)
+		);
+	}
+
+	$form_items[] = (new CFormList())->addRow(
+		new CLabel($data['type'] == ZBX_SCRIPT_TYPE_WEBHOOK ? _('Response') : _('Output')),
+		$row_decription
+	);
+}
+
+$form = (new CForm())->addItem($form_items);
+
 $output = [
 	'header' => $data['title'],
-	'body' => (new CForm())
-		->addItem([
-			$data['errors'],
-			(new CTabView())->addTab('scriptTab', null,
-				(new CPre(
-					(new CList([bold($data['command']), SPACE, $data['message']]))
-				))
-			)
-		])
-		->toString(),
+	'script_inline' => $this->readJsFile('popup.scriptexec.js.php'),
+	'body' => $form->toString(),
 	'buttons' => null
 ];
 
