@@ -306,6 +306,7 @@ class CXmlConstantName {
 	const DISCOVERY = 'DISCOVERY';
 	const AUTOREGISTRATION = 'AUTOREGISTRATION';
 	// const INTERNAL = 'INTERNAL'; // Duplicate.
+	const SERVICE = 'SERVICE';
 
 	const PROBLEM = 'PROBLEM';
 	const RECOVERY = 'RECOVERY';
@@ -335,6 +336,7 @@ class CXmlConstantName {
 	const DASHBOARD_WIDGET_TYPE_CLOCK = 'CLOCK';
 	const DASHBOARD_WIDGET_TYPE_GRAPH_CLASSIC = 'GRAPH_CLASSIC';
 	const DASHBOARD_WIDGET_TYPE_GRAPH_PROTOTYPE = 'GRAPH_PROTOTYPE';
+	const DASHBOARD_WIDGET_TYPE_ITEM = 'ITEM';
 	const DASHBOARD_WIDGET_TYPE_PLAIN_TEXT = 'PLAIN_TEXT';
 	const DASHBOARD_WIDGET_TYPE_URL = 'URL';
 
